==> prestashop_1.4.1.0.zip: prestashop/modules/dibs/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{dibs}prestashop>dibs_b508edd89d96e13df300b298143998d3'] = 'DIBS';
$_MODULE['<{dibs}prestashop>dibs_ef3a95ad5c00ef1b4d1d73d2b50bf54c'] = 'DIBS Zahlung API';
$_MODULE['<{dibs}prestashop>dibs_f146cc67c82721f372d15664a9e4a0d6'] = 'Aus Sicherheitsgründen müssen Sie die Schlüssel Nr. 1 und 2, die von der MD5-Kontrolle von DIBS API verwendet werden, einstellen.';
$_MODULE['<{dibs}prestashop>dibs_94c824556baeddc9d8a31710c38fb045'] = 'Sie müssen Ihre Händler-ID einstellen, um DIBS API nutzen zu können.';
$_MODULE['<{dibs}prestashop>dibs_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Konfiguration aktualisiert';
$_MODULE['<{dibs}prestashop>dibs_323d72a644340f9f2152febe46a52259'] = 'Ein DIBS-Konto erhalten';
$_MODULE['<{dibs}prestashop>dibs_2981c3142099b5653c220ac6ed2620c4'] = 'Bitte klicken Sie auf den folgenden Link, um aus dem DIBS-Anmeldeformular zuzugreifen:';
$_MODULE['<{dibs}prestashop>dibs_97e7c9a7d06eac006a28bf05467fcc8b'] = 'Link';
$_MODULE['<{dibs}prestashop>dibs_9a6126fa59acab742993a80fa0ca9340'] = 'Je nach Ihren Sprache und Länder-Regeln, kanndie Formular-Anmeldung unterschiedlich sein.';
$_MODULE['<{dibs}prestashop>dibs_d076f6d79396f176263a61ad3a1fe945'] = 'Bitte klicken Sie auf die entsprechende Flagge:';
$_MODULE['<{dibs}prestashop>dibs_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{dibs}prestashop>dibs_794b8837b6ee6ddc4301f557915f9486'] = 'Logo-Farbe';
$_MODULE['<{dibs}prestashop>dibs_44e1ec6255a91754e4911b16b9fc4d22'] = 'Die Grundfarbe des Logos, das auf der Zahlungsseite angezeigt wird.';
$_MODULE['<{dibs}prestashop>dibs_229a7ec501323b94db7ff3157a7623c9'] = 'Händler-ID';
$_MODULE['<{dibs}prestashop>dibs_b305acae66879c527cda4c4ded662585'] = 'Die von DIBS geschickte E-Mail sehen';
$_MODULE['<{dibs}prestashop>dibs_310fc01b7a8c167aa514ccccc9e46e99'] = 'Sicherheitsschlüssel Nr. 1';
$_MODULE['<{dibs}prestashop>dibs_247cc6885be1cb649d05acf81242cc35'] = 'Sicherheitsschlüssel Nr. 2';
$_MODULE['<{dibs}prestashop>dibs_c7138fc31d63f966e368147a0cd4e55d'] = 'Diese Schlüssel werden für eine Verbesserung der Sicherheit eingesetzt.';
$_MODULE['<{dibs}prestashop>dibs_b89642757f7199e37e74dd6a9a333733'] = 'Um diese Schlüssel zu erhalten, gehen auf die DIBS-Administrationsoberfläche  zu Integration > MD5 Schlüsselmenü . Bitte stellen Sie sicher, dass die MD5-Kontrolle aktiviert ist, sonst funktioniert das Modul nicht .';
$_MODULE['<{dibs}prestashop>dibs_f9986472f2190b1ec04c52dd1eca1af4'] = 'Verwenden Sie das DIBS-Testmodul';
$_MODULE['<{dibs}prestashop>dibs_313ada9ae4162978238c99d505bb6870'] = 'Sobald dieses Feld mitgeteilt ist, wird die Transaktion nicht zum Karteninhaber weitergeleitet, sondern wird anstattdessen vom DIBS-Testmodul bearbeitet.';
$_MODULE['<{dibs}prestashop>dibs_41f538d798be040c3710e4e128105ad2'] = 'Siehe auch Schritt 5 der 10 Schritt-Anleitung für weitere Informationen.';
$_MODULE['<{dibs}prestashop>dibs_9d0ac8297882a62456cd41249c36d9af'] = 'Während Ihrer ersten Integration mit DIBS ist es nicht nötig, diese Einstellung einzugeben, da sämtliche Standardtransaktionen zunächst auf das DIBS-Testsystem treffen, bis DIBS die Integration genehmigt hat. Falls das Testsystem zu einem späteren Zeitpunkt verwendet wird, wird dies bei DIBS aktiviert (kontaktieren Sie den DIBS-Support, um das Testmodul Ihres Shops zu reaktivieren).';
$_MODULE['<{dibs}prestashop>dibs_58768109d694bef3c059544892118901'] = 'Flexwin-Farbe';
$_MODULE['<{dibs}prestashop>dibs_37b0d284e5d29973b385ca537272ec38'] = 'Die Grundfarbe von FlexWin.';
$_MODULE['<{dibs}prestashop>dibs_2e2b79996d4fb73bff9b97725ddfbab8'] = 'Akzeptierte URL';
$_MODULE['<{dibs}prestashop>dibs_0e260f9297ec338abbf671829d53c4ae'] = 'Die URL der Seite, die angezeigt werden soll, wenn der Kauf genehmigt ist.';
$_MODULE['<{dibs}prestashop>dibs_fcb9c3f1b9731de08442d81583782db7'] = 'Gelöschte URL';
$_MODULE['<{dibs}prestashop>dibs_491f74497aaca60ae31a327d12d52925'] = 'Die URL der Seite, die angezeigt werden soll, wenn der Kunde den Zahlungsvorgang abbricht.';
$_MODULE['<{dibs}prestashop>dibs_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{dibs}prestashop>dibs_b64af11b4f643164b0b418c716a6f7a0'] = 'Mit dibs zahlen';
$_MODULE['<{dibs}prestashop>dibs_fda89beb6740540db1053016d96624c3'] = 'dibs Logo';
$_MODULE['<{dibs}prestashop>dibs_eeaf35c1eb180cc38a77b892a96d7ed3'] = 'Bezahlen Sie sicher und schnell mit dibs.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Ihre Bestellung vom';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'ist abgeschlossen.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Ihre Bestellung wird so schnell wie möglich zugeschickt.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Bei Fragen oder für weitere Informationen, kontaktieren Sie bitte unseren';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'Kunden-Support';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Wir haben bei Ihrer Bestellung ein Problem festgestellt. Wenn Sie denken, dies sei ein Fehler, können Sie an unseren';

==> prestashop_1.4.2.5.zip: prestashop/modules/dibs/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{dibs}prestashop>dibs_b64af11b4f643164b0b418c716a6f7a0'] = 'Mit dibs zahlen';
$_MODULE['<{dibs}prestashop>dibs_fda89beb6740540db1053016d96624c3'] = 'dibs Logo';
$_MODULE['<{dibs}prestashop>dibs_eeaf35c1eb180cc38a77b892a96d7ed3'] = 'Bezahlen Sie sicher und schnell mit dibs.';
$_MODULE['<{dibs}prestashop>dibs_b508edd89d96e13df300b298143998d3'] = 'DIBS';
$_MODULE['<{dibs}prestashop>dibs_ef3a95ad5c00ef1b4d1d73d2b50bf54c'] = 'DIBS Zahlung API';
$_MODULE['<{dibs}prestashop>dibs_f146cc67c82721f372d15664a9e4a0d6'] = 'Aus Sicherheitsgründen müssen Sie die Schlüssel Nr. 1 und 2, die von der MD5-Kontrolle von DIBS API verwendet werden, einstellen.';
$_MODULE['<{dibs}prestashop>dibs_94c824556baeddc9d8a31710c38fb045'] = 'Sie müssen Ihre Händler-ID einstellen, um DIBS API nutzen zu können.';
$_MODULE['<{dibs}prestashop>dibs_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Konfiguration aktualisiert';
$_MODULE['<{dibs}prestashop>dibs_323d72a644340f9f2152febe46a52259'] = 'Ein DIBS-Konto erhalten';
$_MODULE['<{dibs}prestashop>dibs_a24f296af38bde709dffc364b28bdebb'] = 'Klicken Sie bitte auf den Link, um den DIBS Anmeldeformular zu sehen:';
$_MODULE['<{dibs}prestashop>dibs_97e7c9a7d06eac006a28bf05467fcc8b'] = 'Link';
$_MODULE['<{dibs}prestashop>dibs_9a6126fa59acab742993a80fa0ca9340'] = 'Je nach Ihren Sprache und Länder-Regeln, kanndie Formular-Anmeldung unterschiedlich sein.';
$_MODULE['<{dibs}prestashop>dibs_d076f6d79396f176263a61ad3a1fe945'] = 'Bitte klicken Sie auf die entsprechende Flagge:';
$_MODULE['<{dibs}prestashop>dibs_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{dibs}prestashop>dibs_794b8837b6ee6ddc4301f557915f9486'] = 'Logo-Farbe';
$_MODULE['<{dibs}prestashop>dibs_44e1ec6255a91754e4911b16b9fc4d22'] = 'Die Grundfarbe des Logos, das auf der Zahlungsseite angezeigt wird.';
$_MODULE['<{dibs}prestashop>dibs_229a7ec501323b94db7ff3157a7623c9'] = 'Händler-ID';
$_MODULE['<{dibs}prestashop>dibs_b305acae66879c527cda4c4ded662585'] = 'Die von DIBS geschickte E-Mail sehen';
$_MODULE['<{dibs}prestashop>dibs_310fc01b7a8c167aa514ccccc9e46e99'] = 'Sicherheitsschlüssel Nr. 1';
$_MODULE['<{dibs}prestashop>dibs_247cc6885be1cb649d05acf81242cc35'] = 'Sicherheitsschlüssel Nr. 2';
$_MODULE['<{dibs}prestashop>dibs_c7138fc31d63f966e368147a0cd4e55d'] = 'Diese Schlüssel werden für eine Verbesserung der Sicherheit eingesetzt.';
$_MODULE['<{dibs}prestashop>dibs_b89642757f7199e37e74dd6a9a333733'] = 'Um diese Schlüssel zu erhalten, gehen auf die DIBS-Administrationsoberfläche  zu Integration > MD5 Schlüsselmenü . Bitte stellen Sie sicher, dass die MD5-Kontrolle aktiviert ist, sonst funktioniert das Modul nicht .';
$_MODULE['<{dibs}prestashop>dibs_f9986472f2190b1ec04c52dd1eca1af4'] = 'Verwenden Sie das DIBS-Testmodul';
$_MODULE['<{dibs}prestashop>dibs_313ada9ae4162978238c99d505bb6870'] = 'Sobald dieses Feld mitgeteilt ist, wird die Transaktion nicht zum Karteninhaber weitergeleitet, sondern wird anstattdessen vom DIBS-Testmodul bearbeitet.';
$_MODULE['<{dibs}prestashop>dibs_41f538d798be040c3710e4e128105ad2'] = 'Siehe auch Schritt 5 der 10 Schritt-Anleitung für weitere Informationen.';
$_MODULE['<{dibs}prestashop>dibs_9d0ac8297882a62456cd41249c36d9af'] = 'Während Ihrer ersten Integration mit DIBS ist es nicht nötig, diese Einstellung einzugeben, da sämtliche Standardtransaktionen zunächst auf das DIBS-Testsystem treffen, bis DIBS die Integration genehmigt hat. Falls das Testsystem zu einem späteren Zeitpunkt verwendet wird, wird dies bei DIBS aktiviert (kontaktieren Sie den DIBS-Support, um das Testmodul Ihres Shops zu reaktivieren).';
$_MODULE['<{dibs}prestashop>dibs_58768109d694bef3c059544892118901'] = 'Flexwin-Farbe';
$_MODULE['<{dibs}prestashop>dibs_37b0d284e5d29973b385ca537272ec38'] = 'Die Grundfarbe von FlexWin.';
$_MODULE['<{dibs}prestashop>dibs_2e2b79996d4fb73bff9b97725ddfbab8'] = 'Akzeptierte URL';
$_MODULE['<{dibs}prestashop>dibs_0e260f9297ec338abbf671829d53c4ae'] = 'Die URL der Seite, die angezeigt werden soll, wenn der Kauf genehmigt ist.';
$_MODULE['<{dibs}prestashop>dibs_fcb9c3f1b9731de08442d81583782db7'] = 'Gelöschte URL';
$_MODULE['<{dibs}prestashop>dibs_491f74497aaca60ae31a327d12d52925'] = 'Die URL der Seite, die angezeigt werden soll, wenn der Kunde den Zahlungsvorgang abbricht.';
$_MODULE['<{dibs}prestashop>dibs_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Ihre Bestellung vom';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'ist abgeschlossen.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Ihre Bestellung wird so schnell wie möglich zugeschickt.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Bei Fragen oder für weitere Informationen, kontaktieren Sie bitte unseren';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'Kunden-Support';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Wir haben bei Ihrer Bestellung ein Problem festgestellt. Wenn Sie denken, dies sei ein Fehler, können Sie an unseren';

?>
